#! /usr/bin/env bash
rm -rf pkg pkg_node pkg_web pkg2_node pkg2_web pkg2

######################################
# ARROW 1 (arrow-rs) the default feature
# Build node version into pkg_node
echo "Building arrow-rs node"
wasm-pack build \
  --release \
  --out-dir pkg_node \
  --out-name node \
  --target nodejs

# Build web version into pkg_web
echo "Building arrow-rs web"
wasm-pack build \
  --release \
  --out-dir pkg_web \
  --out-name web \
  --target web

# Build standard bundler version into pkg
echo "Building arrow-rs bundler"
wasm-pack build \
  --release \
  --out-dir pkg \
  --out-name bundler \
  --target bundler

######################################
# ARROW 2 turn on the feature manually
# Build node version into pkg2_node
echo "Building arrow2 node"
wasm-pack build \
  --release \
  --out-dir pkg2_node \
  --out-name node2 \
  --target nodejs \
  --no-default-features \
  --features arrow2 \
  --features reader \
  --features writer \
  --features parquet2_supported_compressions

# Build web version into pkg2_web
echo "Building arrow2 web"
wasm-pack build \
  --release \
  --out-dir pkg2_web \
  --out-name web2 \
  --target web \
  --no-default-features \
  --features arrow2 \
  --features reader \
  --features writer \
  --features parquet2_supported_compressions

# Build standard bundler version into pkg2
echo "Building arrow2 bundler"
wasm-pack build \
  --release \
  --out-dir pkg2 \
  --out-name bundler2 \
  --target bundler \
  --no-default-features \
  --features arrow2 \
  --features reader \
  --features writer \
  --features parquet2_supported_compressions

# Copy files into pkg/
cp pkg_node/{node.d.ts,node.js,node_bg.wasm,node_bg.wasm.d.ts} pkg/
cp pkg_web/{web.d.ts,web.js,web_bg.wasm,web_bg.wasm.d.ts} pkg/

cp pkg2_node/{node2.d.ts,node2.js,node2_bg.wasm,node2_bg.wasm.d.ts} pkg/
cp pkg2_web/{web2.d.ts,web2.js,web2_bg.wasm,web2_bg.wasm.d.ts} pkg/
cp pkg2/{bundler2.d.ts,bundler2.js,bundler2_bg.wasm,bundler2_bg.wasm.d.ts} pkg/

# Update files array using JQ
jq '.files += [
  "node.d.ts", "node.js", "node_bg.wasm", "node_bg.wasm.d.ts",
  "web.d.ts", "web.js", "web_bg.wasm", "web_bg.wasm.d.ts",

  "node2.d.ts", "node2.js", "node2_bg.wasm", "node2_bg.wasm.d.ts",
  "web2.d.ts", "web2.js", "web2_bg.wasm", "web2_bg.wasm.d.ts",
  "bundler2.d.ts", "bundler2.js", "bundler2_bg.wasm", "bundler2_bg.wasm.d.ts"
  ]' pkg/package.json > pkg/package.json.tmp
# Overwrite existing file
mv pkg/package.json.tmp pkg/package.json
